var Product = require('/ui/common/product/Product');
var Utils = require('/ui/common/lib/Utils');

function MasterView() {

	var View = require('/ui/common/views/View');
	View.call(this);
	if ( typeof MasterView.initialized == "undefined") {
		for (var element in View.prototype ) {
			MasterView.prototype[element] = View.prototype[element]
		}
		MasterView.initialized = true;
	}
	Titanium.UI.orientation = Titanium.UI.LANDSCAPE_LEFT;

	this.domain = "";
	this.domainInvalid = false;
	this.lastRequestFailed = false;
	this.nbActivityIndicatorOpen = 0;
	this.emptyTableView

	var win = Titanium.UI.createWindow({
		navBarHidden : true,
		backgroundColor : this.getDTC().colors.black,
	});

	this.tab = Titanium.UI.createTab({
		window : win
	});

	this.tableView = Ti.UI.createTableView({
		top : this.getDTC().sizes.headerHeight,
		backgroundColor : this.getDTC().colors.grey,
		separatorColor : this.getDTC().colors.grey,
	});

	this.view = Ti.UI.createView();

	//Loading Window
	this.activityIndicator = Ti.UI.createActivityIndicator({
		color : this.getDTC().colors.red,
		font : {
			fontFamily : this.getDTC().fonts.fontFamily,
			fontSize : this.getDTC().sizes.labelH1,
			fontWeight : 'bold'
		},
		message : this.getDTC().lang.loading,
		top : 10,
		left : 10,
		height : 'auto',
		width : 'auto'
	});

	if (Ti.Platform.name === 'iPhone OS')
		this.view.add(this.activityIndicator);

	//Header
	var Header = require('/ui/common/views/shared/Header');
	this.header = new Header();

	//Products
	this.products = new Array();

	//We create each product one time
	if (Ti.App.Properties.getList("products") == null) {
		Ti.API.debug("No default services list found. Load defaults services.");
		Ti.App.Properties.setList("products", Ti.App.Config.getProducts());
	} else {
		Ti.API.debug("Services list found.");
	}
	//We create one product object for each product
	this.initProducts();
	//We generate the tableview
	this.generateTableView(Ti.App.Properties.getList("products"));

	//Presentation
	var PresentationView = require('/ui/common/views/shared/PresentationView');
	presentationView = new PresentationView();

	this.view.add(this.header.viewHeader);
	this.view.add(this.tableView);

	if (Ti.App.Properties.getBool('presentationTexts') == null) {
		Ti.App.Properties.setBool('presentationTexts', true)
	}
	if (Ti.App.Properties.getBool('helpTexts') == null) {
		Ti.App.Properties.setBool('helpTexts', true)
	}
	if (Ti.App.Properties.getBool('presentationTexts') || Ti.App.Properties.getBool('presentationTexts') == null) {
		this.view.add(presentationView.viewPresentationView);
	}

	//If the user press return, we refresh all opened services
	var that = this;
	this.header.tfDomain.addEventListener('return', function(e) {
		Ti.API.debug("Return");
		Ti.App.fireEvent('blur', null);
		that.domainInvalid = false;
		if (!that.emptyTableView) {
			for (var j = 0; j < that.tableView.data[0].rowCount; j++) {
				Ti.API.debug("j" + j + " " + that.tableView.data[0].rows[j].options.visible + " " + that.tableView.data[0].rows[j].result);
				if (j == 1 || that.tableView.data[0].rows[j].options.visible && that.tableView.data[0].rows[j].result) {
					Ti.API.debug("Notify " + that.tableView.data[0].rows[j].options.name);
					that.tableView.data[0].rows[j].options.service.notify(that.tableView.data[0].rows[j]);
				}
			}
		}
		else{
			alert(that.getDTC().lang.select_a_domain_manager);
		}
	});
	return this;
};

MasterView.prototype.checkEmptyTableView = function() {
	Ti.API.debug("checkEmptyTableView");
	if (!Utils.isDefined(this.tableView.data[0]) || Utils.isDefined(this.tableView.data[0].rowCount == 0)) {
		Ti.API.debug("is Empty");
		this.emptyTableView = true;
		var label = Titanium.UI.createLabel(this.getStyleOf("title", "centered"));
		label.setColor(this.getDTC().colors.white);
		label.setText(this.getDTC().lang.no_product);
		label.setTop(1);
		var subLabel = Titanium.UI.createLabel(this.getStyleOf("title", "small_centered"));
		subLabel.setText(this.getDTC().lang.no_product_howto);
		subLabel.setColor(this.getDTC().colors.white);
		subLabel.setTop(this.getDTC().sizes.resultsMargin * 2);
		var view = Ti.UI.createView();
		view.add(label);
		view.add(subLabel);
		var row = Ti.UI.createTableViewRow({
			result : false,
			hasChild : false,
			backgroundColor : this.getDTC().colors.red,
		});
		row.add(view);
		this.tableView.appendRow(row);
	}
}

MasterView.prototype.getProducts = function() {
	return Ti.App.Properties.getList("products");
}

MasterView.prototype.initProducts = function() {
	for (var i = 0; i < Ti.App.Properties.getList("products").length; i++) {
		this.createProduct(Ti.App.Properties.getList("products")[i], i);
		if (Ti.App.Properties.getBool(Ti.App.Properties.getList("products")[i]) == null) {
			Ti.API.debug("No cookie on " + Ti.App.Properties.getList("products")[i]);
			Ti.App.Properties.setBool(Ti.App.Properties.getList("products")[i], true);
		}
	}
}

MasterView.prototype.createProduct = function(product, position) {
	this.products[product] = new Product({
		position : position,
		tableView : this.tableView,
		name : product,
		header : this.header,
		masterView : this,
		visible : false,
	});
}

MasterView.prototype.generateTableView = function(products) {
	var position = 0;
	//We loop on each products
	for (var i = 0; i < Ti.App.Properties.getList("products").length; i++) {
		// products only contains the order of products.
		//To know if a product is visible or not, we have to look into the cookies
		var productCookieIsNull = Ti.App.Properties.getBool(Ti.App.Properties.getList("products")[i]) == null;
		var productIsVisible = Ti.App.Properties.getBool(products[i]);
		Ti.API.debug("productCookieIsNull " + productCookieIsNull + " productIsVisible " + productIsVisible);
		if (productCookieIsNull || productIsVisible) {
			//Add a new product
			Ti.API.debug("Add " + products[i] + " services");
			this.tableView.appendRow(this.products[Ti.App.Properties.getList("products")[i]].rows);
		} else {
			Ti.API.debug(Ti.API.debug("Don't add " + products[i] + " services"));
		}
	}
	this.checkEmptyTableView();
	this.hideActivityIndicator();
}

MasterView.prototype.moveProduct = function(product, index, action) {
	//If the product is visible, we have to move it
	if (Ti.App.Properties.getBool(product)) {
		if (action == 'up')
			this.moveUpProduct(product);
		else
			this.moveDownProduct(product);
	}
	this.hideActivityIndicator();
}

MasterView.prototype.moveUpProduct = function(product) {
	//If the other product to switch is not visible, we don't have to switch
	for (var i = 0; i < Ti.App.Properties.getList("products").length; i++) {
		if (Ti.App.Properties.getList("products")[i] == product) {
			if (Ti.App.Properties.getBool(Ti.App.Properties.getList("products")[i - 1])) {
				//The product is visible, we have to switch
				//We search for the product to switch
				for (var j = 0; j < this.tableView.data[0].rowCount; j++) {
					Ti.API.debug("j" + j + " " + this.tableView.data[0].rows[j]);
					this.tableView.data[0].rows[j].options.visible = false;
					if (this.tableView.data[0].rows[j].options.name == product) {
						//We have found the product. So we switch with the product up
						this.tableView.data[0].rows[j].options.position--;
						this.tableView.data[0].rows[j - 2].options.position++;
						//-2 because a product contains two rows (the button and the result)
						this.tableView.deleteRow(j);
						this.tableView.deleteRow(j);
						this.tableView.insertRowBefore(j - 2, this.products[product].rows[1]);
						this.tableView.insertRowBefore(j - 2, this.products[product].rows[0]);
						break;
					}
				}
			}
		}
	}
}

MasterView.prototype.moveDownProduct = function(product) {
	//If the other product to switch is not visible, we don't have to switch
	for ( i = Ti.App.Properties.getList("products").length; i >= 0; i--) {
		if (Ti.App.Properties.getList("products")[i] == product) {
			if (Ti.App.Properties.getBool(Ti.App.Properties.getList("products")[i + 1])) {
				Ti.API.debug("We have to switch " + product);
				//The product is visible, we have to switch
				//We search for the product to switch
				for (var j = 0; j < this.tableView.data[0].rowCount; j++) {
					this.tableView.data[0].rows[j].options.visible = false;
					if (this.tableView.data[0].rows[j].options.name == product) {
						//We have found the product. So we switch with the product down
						this.tableView.data[0].rows[j].options.position++;
						//the product to move goes down
						this.tableView.data[0].rows[j + 2].options.position--;
						//-2 because a product contains two rows (the button and the result)the product down goes up
						this.tableView.deleteRow(j);
						this.tableView.deleteRow(j);
						Ti.API.debug("delete " + product + " reinsert after " + (j + 1) + " " + this.tableView.data[0].rows[j].options.name);
						this.tableView.insertRowAfter(j + 1, this.products[product].rows[1]);
						this.tableView.insertRowAfter(j + 1, this.products[product].rows[0]);
						break;
					}
				}
			}
		}
	}
}

MasterView.prototype.showActivityIndicator = function() {
	this.nbActivityIndicatorOpen++;
	this.activityIndicator.show();
	Ti.API.debug("Number of ActivityIndicator " + this.nbActivityIndicatorOpen);
}

MasterView.prototype.hideActivityIndicator = function() {
	Ti.API.debug("Number of ActivityIndicator " + this.nbActivityIndicatorOpen);
	if (this.nbActivityIndicatorOpen < 2) {
		Ti.API.debug("ActivityIndicator : hide");
		this.activityIndicator.hide();
		this.nbActivityIndicatorOpen = 0;
	} else
		this.nbActivityIndicatorOpen--;
}

MasterView.prototype.toggleProduct = function(product) {
	if (this.emptyTableView) {
		this.tableView.deleteRow(0);
		this.emptyTableView = false;
	}
	Ti.API.debug("toggleProduct product " + product);
	var found = false;
	var show;
	var iVisible = 0;
	//count how many product are visible
	//if the product is show or hide
	//We update the tableView
	for (var i = 0; i < Ti.App.Properties.getList("products").length; i++) {
		// products only contains the order of products.
		//To know if a product is visible or not, we have to look into the cookies
		if (Ti.App.Properties.getList("products")[i] == product) {
			found = true;
			//We set the boolean
			if (Ti.App.Properties.getBool(product)) {
				Ti.App.Properties.setBool(product, false);
				Ti.API.debug("deleteRow " + i);
				this.tableView.deleteRow(iVisible * 2);
				this.tableView.deleteRow(iVisible * 2);
				show = false;
				this.checkEmptyTableView();
			} else {
				Ti.API.debug("show " + product);
				Ti.App.Properties.setBool(product, true);
				//If the tableview doesn't has rows
				if (!Utils.isDefined(this.tableView.data[0]) || this.tableView.data[0].rowCount < 1) {

					this.tableView.appendRow(this.products[Ti.App.Properties.getList("products")[i]].rows[0]);
					this.tableView.appendRow(this.products[Ti.App.Properties.getList("products")[i]].rows[1]);
					this.products[Ti.App.Properties.getList("products")[i]].options.position = 0;
				} else {
					if (iVisible != 0) {
						this.tableView.insertRowAfter((iVisible * 2) - 1, this.products[Ti.App.Properties.getList("products")[i]].rows[1]);
						this.tableView.insertRowAfter((iVisible * 2) - 1, this.products[Ti.App.Properties.getList("products")[i]].rows[0]);
					} else {
						this.tableView.insertRowBefore(0, this.products[Ti.App.Properties.getList("products")[i]].rows[1]);
						this.tableView.insertRowBefore(0, this.products[Ti.App.Properties.getList("products")[i]].rows[0]);
					}
					Ti.API.debug("new position " + iVisible);
					this.products[Ti.App.Properties.getList("products")[i]].options.position = iVisible;
				}
				show = true;
			}
		} else {
			if (Ti.App.Properties.getBool(Ti.App.Properties.getList("products")[i]))
				iVisible++;
			if (found) {
				Ti.API.debug("found");
				//Update positions
				if (show) {
					Ti.API.debug("options.position++");
					this.products[Ti.App.Properties.getList("products")[i]].options.position++;
					Ti.API.debug(Ti.App.Properties.getList("products")[i] + " new position " + this.products[Ti.App.Properties.getList("products")[i]].options.position);
				} else {
					Ti.API.debug("options.position--");
					this.products[Ti.App.Properties.getList("products")[i]].options.position--;
					Ti.API.debug(Ti.App.Properties.getList("products")[i] + " new position " + this.products[Ti.App.Properties.getList("products")[i]].options.position);
				}
			}
		}
	}
	this.hideActivityIndicator();
}

MasterView.prototype.alertDomainInvalid = function(msg, value) {
	Ti.API.debug("alertDomainInvalid " + msg + " " + value);
	if (!this.domainInvalid) {
		Ti.API.debug("first alert");
		this.domainInvalid = true;
		if (Utils.isDefined(this.getDTC().lang[msg])) {
			var string = this.getDTC().lang[msg];
			string = string.replace('ø', value);
			alert(string);
		} else {
			alert(msg);
		}
	} else {
		Ti.API.debug("alert already sent");
	}
	this.hideAllProducts();
	this.hideActivityIndicator();
}

MasterView.prototype.hideAllProducts = function() {
	for (var j = 0; j < this.tableView.data[0].rowCount; j++) {
		if (this.tableView.data[0].rows[j].options.name != Ti.App.Config.getProducts()[0]) {
			this.tableView.data[0].rows[j].options.service.hide();
			this.tableView.data[0].rows[j].options.service.resultAvailable = false;
		}
	}
}

module.exports = MasterView;
