var Utils = require('/ui/common/lib/Utils');

function Service(options) {
	this.resultAvailable = false;
	this.options = options;
	this.xmlReadPosition = false;
	var Result = require('/ui/common/views/ResultView');
	this.results = new Result(options);
	return this;
}

Service.prototype.readData = function(data) {
	//Test if data is a digit
	if (Ti.App.Utils.isInt(data)) {
		return data.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ",");
	}
	return data;
}

Service.prototype.getFirstNodeText = function(nodeName) {
	if (this.xmlReadPosition.getElementsByTagName(nodeName).length > 0)
		return this.readData(this.xmlReadPosition.getElementsByTagName(nodeName).item(0).textContent);
	return "";
}

Service.prototype.getNodeTextAt = function(nodeName, i) {
	if (this.xmlReadPosition.getElementsByTagName(nodeName).length > i)
		return this.readData(this.xmlReadPosition.getElementsByTagName(nodeName).item(i).textContent);
	return "";
}

Service.prototype.getNbNodes = function(nodeName) {
	return this.xmlReadPosition.getElementsByTagName(nodeName).length;
}

Service.prototype.getDomain = function(domain) {
	//We test if the domain contains a Tld
	if (domain.indexOf('.') == -1) {
		//We test the Tld
		if (domain.indexOf(Ti.App.Properties.getString('defaultTld')) != null) {
			if (domain.indexOf(Ti.App.Properties.getString('defaultTld')) == -1) {
				//Adding the default Tld
				domain = domain + Ti.App.Properties.getString('defaultTld');
				this.options.header.tfDomain.setValue(domain);
			}
		}
	}
	Ti.include('/ui/common/lib/Punycode.js');
	return punycode.ToASCII(Ti.App.Utils.trim(domain));
}

Service.prototype.sendRequest = function(url,timeout) {
	if(!Utils.isDefined(timeout)) timeout = Ti.App.Config.getTimeout();
	Ti.API.debug("sendRequest "+url+" timeout "+timeout);
	var that = this;
	var client = Ti.Network.createHTTPClient({
		// function called when the response data is available
		onload : function(e) {
			if (this.responseXML == null) {
				that.results.noInternet();
			} else {
				Ti.API.debug(that.options.name +"'s request Successful");
				Ti.API.debug(this.responseXML.documentElement);
				that.xmlReadPosition = this.responseXML.documentElement;
				that.options.masterView.lastRequestFailed = false;
				that.load();
				that.resultAvailable = true;
			}
		},
		// function called when an error occurs, including a timeout
		onerror : function(e) {
			Ti.API.debug("Error "+e.error);
			if(!that.options.masterView.lastRequestFailed){
				that.options.masterView.alertDomainInvalid(e.error);
			}
			that.hide();
			that.options.masterView.lastRequestFailed = true;
		},
		timeout : timeout
	});
	this.serviceFailed = false;
	client.open("GET", url);
	client.send();
}

Service.prototype.notify = function() {
	//We test if internet is available
	if(!Titanium.Network.online){
		Ti.API.debug("no Internet");
		this.results.noInternet();
	} 
	else{ 
		Ti.API.debug("Notify "+this.options.name+" domain is valid ? "+!this.options.masterView.domainInvalid);
		
		Ti.API.debug("Domain changed ? "+(this.domain != this.options.header.tfDomain.value) + " result Available ? "+this.resultAvailable);
		if (this.domain != this.options.header.tfDomain.value){
			this.resultAvailable = false;
		} 
		//If the domain has changed, the user will execute a new request
		if(!this.resultAvailable) {
			Ti.API.debug("Results not available");
			this.options.masterView.lastRequestFailed = false;
			if(!this.options.masterView.domainInvalid){
				Ti.API.debug("Domain is not invalid");
				this.options.masterView.showActivityIndicator();
				this.deleteResults();
				this.domain = this.options.header.tfDomain.value;
				if (this.isDomain(this.getDomain(this.domain))) {
					Ti.API.debug("executeRequest");
					this.options.masterView.domainInvalid = false;
					this.executeRequest();
				}else{
					Ti.API.debug("Domain is Invalid");
					this.resultAvailable = false;
					this.options.masterView.domainInvalid = true;
				} 
			}
		} else {
			Ti.API.debug("Results available");
			//If the user click on the button
			// And the view is open, we collapse it
			if (this.options.visible) this.hide();
			// Else we open it
			else  this.show();
		}
	}
}

Service.prototype.hide = function() {
	this.results.hide();
}

Service.prototype.show = function() {
	this.results.show();
}

Service.prototype.deleteResults = function() {
	this.results.init();
}

Service.prototype.getDomainTld = function(domain){
	var dot = domain.lastIndexOf(".");
	return dname = domain.substring(dot+1, domain.length);
}

Service.prototype.getDomainWithoutTld = function(domain){
	var array = domain.split('.');
	return array[array.length-2]
}

Service.prototype.isDomain = function(string) {
	if(this.getDomainWithoutTld(string).length<1){
		this.alertDomainInvalid('select_a_domain');
		return false;
	} 
	var arr = Ti.App.Config.getTlds();
	var mai = string;
	var val = true;
	var dot = mai.lastIndexOf(".");
	var dname = mai.substring(0, dot);
	var ext = mai.substring(dot, mai.length);
		for (var i = 0; i < arr.length; i++) {	
			if (ext.toLowerCase()  == arr[i].toLowerCase() ) {
				val = true;
				break;
			} else {
				val = false;
			}
		}
		if (val == false) {
			this.alertDomainInvalid('domain_extension_not_correct',ext);
			return false;
		} else {
			//Test each characters
			for (var j = 0; j < dname.length; j++) {
				var dh = dname.charAt(j);
				var hh = dh.charCodeAt(0);
				if ((hh > 47 && hh < 59) || (hh > 64 && hh < 91) || (hh > 96 && hh < 123) || hh == 45 || hh == 46) {
					if ((j == 0 || j == dname.length - 1) && hh == 45) {
						this.alertDomainInvalid('domain_name_minus');
						return false;
					}
				} else {
					this.alertDomainInvalid('domain_special_characters');
					return false;
				}
			}
		}
	return true;
}

Service.prototype.alertDomainInvalid = function(msg, value){
	this.options.masterView.alertDomainInvalid(msg,value);
}

module.exports = Service;