var Service = require('/ui/common/services/Service');
var Utils = require('/ui/common/lib/Utils');
var Signer = require('/ui/common/lib/Signer');

function ServiceDomainProfile(options) {
	var Service = require('/ui/common/services/Service');
	Service.call(this, options);
	return this;
}

Utils.inherit(ServiceDomainProfile, Service);

ServiceDomainProfile.prototype.executeRequest = function() {
	var domain = this.getDomain(this.options.header.tfDomain.value);
	var uri = '/v1/' + domain;
	var url = Signer.getURL(uri);
	this.sendRequest(url);
}

ServiceDomainProfile.prototype.load = function() {
	var i = 0; //we count product_url
	var j;
	//Test if the domain is available
	var statusAvailable = this.getFirstNodeText('statuses') == 'available';
	var statusIsNotDefined = !Utils.isDefined(this.getFirstNodeText('statuses'));
	var nameIsNotDefined = !Utils.isDefined(this.getFirstNodeText('name'));
	var ipAdressIsNotDefined = !Utils.isDefined(this.getFirstNodeText('ip_address'));
	Ti.API.debug(statusAvailable+" "+statusIsNotDefined);
	if (statusAvailable || statusIsNotDefined && nameIsNotDefined && ipAdressIsNotDefined) {
		this.results.addTitle('notRegistered');
		var url = 'http://www.domaintools.com/redirect/mobile/android/?domains=' + this.getDomain(this.options.header.tfDomain.value) + '&uuid=' + Titanium.Platform.id;
		this.results.addLinkDomainAvailable('buyThisDomainName', 'buyThisDomainName', url);
	} else {		
		if(Utils.isDefined(this.getFirstNodeText('created')) || Utils.isDefined(this.getFirstNodeText('expires')) || Utils.isDefined(this.getFirstNodeText('updated'))){
			this.results.addTitle('registration');
		}
		this.results.addLabel('created', this.getFirstNodeText('created'));
		this.results.addLabel('expires', this.getFirstNodeText('expires'));
		this.results.addLabel('updated', this.getFirstNodeText('updated'));
		if (this.getNbNodes('registrar') > 1)
			this.results.addLabel('registrar', this.getFirstNodeText('registrar'));
		//Registered with
		if (this.getNbNodes('statuses') > 0) {
			var listStatuses = new Array();
			for ( j = 0; j < this.getNbNodes('statuses'); j++) {
				listStatuses[j] = this.getNodeTextAt('statuses', j);
			}
			this.results.addList('statuses', listStatuses);
		}
		//Reverse Whois
		if (this.getNbNodes('domains') > 0) {
			var other_domains = new Array();
			other_domains[0] = this.getNodeTextAt('domains', 0);
			Ti.API.info("other_domains "+other_domains);
			if (other_domains[0] > 0) {
				this.results.addBreak();
				this.results.addTitle('registrant', this.getFirstNodeText('name'));
				if(other_domains[0]>1)
					this.results.addLinkMultiValues('reverse_whois_domains', other_domains, this.getNodeTextAt('product_url', i++));
				else
					this.results.addLinkMultiValues('reverse_whois_domain', other_domains, this.getNodeTextAt('product_url', i++));	
			}
		}
		var ipAddress = new Array();
		ipAddress[0] = this.getFirstNodeText('ip_address');
		ipAddress[1] = this.getFirstNodeText('other_domains');
		if (Utils.isDefined(ipAddress[0])) {
			this.results.addBreak();
			this.results.addTitle('ip_address');
			if (ipAddress[1] == 0)
				this.results.addLinkMultiValues('other_no_domain', ipAddress, this.getNodeTextAt('product_url', i++));
			if (ipAddress[1] == 1)
				this.results.addLinkMultiValues('other_domain', ipAddress, this.getNodeTextAt('product_url', i++));
			else
				this.results.addLinkMultiValues('other_domains', ipAddress, this.getNodeTextAt('product_url', i++));
		}
		if (this.getNbNodes('server') > 1) {
			this.results.addBreak();
			this.results.addTitle('servers');
			for ( j = 1; j < this.getNbNodes('server'); j++)
				this.results.addLink('nameserver', this.getNodeTextAt('server', j), this.getNodeTextAt('product_url', i++));
		}
		if (this.getFirstNodeText('events') > 0 || this.getNodeTextAt('events', 1) > 0 || this.getNodeTextAt('events', 2) > 0 || this.getFirstNodeText('records') > 0) {
			this.results.addBreak();
			this.results.addTitle('historical_records');
		}
		// x registrar changes sinces y
		if (this.getFirstNodeText('events') > 0) {
			var registrar = new Array();
			registrar[0] = this.getFirstNodeText('events');
			registrar[1] = this.getFirstNodeText('earliest_event');
			if (registrar[0] > 0)
				this.results.addLinkMultiValues('registrar_changes', registrar, this.getNodeTextAt('product_url', i++));
		}
		// x name server changes in y years
		if (this.getNodeTextAt('events', 1) > 0) {
			var ns_changes = new Array();
			ns_changes[0] = this.getNodeTextAt('events', 1);
			ns_changes[1] = this.getNodeTextAt('timespan_in_years', 0);
			if (ns_changes[1] == 1)
				this.results.addLinkMultiValues('ns_changes_year', ns_changes, this.getNodeTextAt('product_url', i++));
			else if (ns_changes[1] > 1)
				this.results.addLinkMultiValues('ns_changes_years', ns_changes, this.getNodeTextAt('product_url', i++));
		}
		// x IP address changes in y years
		if (this.getNodeTextAt('events', 2) > 0) {
			var ip_address_changes = new Array();
			ip_address_changes[0] = this.getNodeTextAt('events', 2);
			ip_address_changes[1] = this.getNodeTextAt('timespan_in_years', 1);
			if (ip_address_changes[1] == 1)
				this.results.addLinkMultiValues('ip_address_changes_year', ip_address_changes, this.getNodeTextAt('product_url', i++));
			else if (ip_address_changes[1] > 1)
				this.results.addLinkMultiValues('ip_address_changes_years', ip_address_changes, this.getNodeTextAt('product_url', i++));
		}
		// x IP address changes in y years
		if (Utils.isDefined(this.getFirstNodeText('records')) && this.getFirstNodeText('records') > 0) {
			var whois_history_records = new Array();
			whois_history_records[0] = this.getFirstNodeText('records');
			whois_history_records[1] = this.getNodeTextAt('earliest_event', 1);
			this.results.addLinkMultiValues('whois_history_records', whois_history_records, this.getNodeTextAt('product_url', i++));
		}
		if (Utils.isDefined(this.getFirstNodeText('score'))) {
			this.results.addBreak();
			this.results.addTitle('seo');
			this.results.addLink('score', this.getFirstNodeText('score'), this.getNodeTextAt('product_url', i++));
		}
	}
	this.results.show();
}

module.exports = ServiceDomainProfile;