var Utils = require('/ui/common/lib/Utils');

function View() {
	this.top = 0;
	this.view = Ti.UI.createView();
	return this;
}

View.prototype.getDTC = function() {
	if ( typeof (View.prototype.DTC) == "undefined") {
		Ti.include('/ui/common/config/initializer.js');
		View.prototype.DTC = DTC;
	}
	return View.prototype.DTC;
}
/**
 * Receive a Date like '2001-03-04' and return it like '12 years ago'
 * @param {String} value a Data 2001-03-04
 */
View.prototype.changeDateInYearsAgo = function(value) {
	var currentTime = new Date()
	var dateParts = value.split('-');
	var yearsAgo = currentTime.getFullYear() - dateParts[0];
	if (yearsAgo > 1)
		return yearsAgo + this.getDTC().lang.yearsAgo;
	else
		return yearsAgo + this.getDTC().lang.yearAgo;
}

View.prototype.addBreak = function() {
	this.top += this.getDTC().sizes.resultsMargin;
}

View.prototype.addTitle = function(attr, value) {
	this.createElement("title", attr, value, "result");
}

View.prototype.addTitleCentered = function(attr, value) {
	this.createElement("title", attr, value, "centered");
}

View.prototype.addLabel = function(attr, value) {
	this.createElement("label", attr, value, "result");
}

View.prototype.addList = function(attr, list) {
	var value = list[0];
	for (var i = 1; i < list.length; i++) {
		value = value + ', ' + list[i];
	}
	this.createElement("label", attr, value, "result");
}
/**
 * Create a date like '3 years ago'
 * @param {Object} attr
 * @param {String} value a Data 2001-03-04
 */
View.prototype.addDateMath = function(attr, value) {
	this.createElement("label", attr, this.changeDateInYearsAgo(value), "result");
}
/**
 * Create a clickable date like '3 years ago'
 * @param {Object} attr
 * @param {String} value a Data 2001-03-04
 */
View.prototype.addDateMathLink = function(attr, value, url) {
	this.addLink(attr, this.changeDateInYearsAgo(value), url);
}

View.prototype.addBlock = function(attr, value) {
	this.createElement("block", attr, value, "record");
}

View.prototype.addMargin = function(margin) {
	this.top += margin;
}

View.prototype.addLink = function(attr, value, url) {
	this.createElement("label", attr, value, "link", url);
}

View.prototype.addLinkMultiValues = function(attr, value, url) {
	this.createElement("label", attr, value, "link", url, true);
}

View.prototype.addLinkDomainAvailable = function(attr, value, url) {
	this.createElement("image", "image", this.getDTC().images.buy_this_domain, "result", url);
}

View.prototype.addScreenshot = function(small_screenshot_url, url) {
	this.createElement("screenshot", "image", small_screenshot_url, "result", url);
}

View.prototype.createElement = function(type, attr, value, subType, url, multiValues) {
	//We don't add empty labels
	if (!Utils.isDefined(value) && type == "label")
		return false;

	// We get the generic style for this element(title, label)
	var style = this.getStyleOf(type, subType);
	var containerStyle = this.cloneObject(style);

	// we get the localized string
	this.translate(style, attr);
	// we insert the value in the placeholder (if any)
	this.insertValues(style, attr, value, multiValues);
	var container = Ti.UI.createView(containerStyle);

	if (type == 'screenshot')
		var element = this.createScreenshot(value, url);
	else if (type == "image")
		var element = this.createImage(value, url);
	else
		var element = this.createLabel(style, url);

	container.add(element);
	// we add it to the view
	this.addMargin(containerStyle.margin_top);
	this.addElement(container, style);
	this.addMargin(containerStyle.margin_bottom);
}

View.prototype.createLabel = function(style, url) {
	var element = Ti.UI.createLabel(style);
	//If the label has a link, we add a clickListener and underline it
	if (Utils.isDefined(url)) {
		element.html = '<u>' + style.text + '</u>';
		element.text = '';
		element.addEventListener('click', function() {
			Titanium.Platform.openURL(url);
		});
	}
	return element;
}

View.prototype.translate = function(style, attr) {
	style.text = this.getDTC().lang[attr];
}
/**
 * Insert values in style's slots
 */
View.prototype.insertValues = function(style, attr, value, multiValues) {
	if ( typeof (style.text) != "undefined") {
		if (multiValues) {
			if (value[0] != 0)
				style.text = style.text.replace('ø', value[0]);
			if (value[1] != 0)
				style.text = style.text.replace('§', value[1]);
		} else {
			style.text = style.text.replace('ø', value);
		}
	}
}

View.prototype.createImage = function(image, url) {
	var element = Ti.UI.createImageView({
		image : image,
	});
	if (Utils.isDefined(url)) {
		element.addEventListener('click', function() {
			Titanium.Platform.openURL(url);
		});
	}
	return element;
}
/**
 * Create and return an ImageView
 * If large_screenshot_url is not null, we check if the screenshot exists and we add a link on it
 */
View.prototype.createScreenshot = function(small_screenshot_url, large_screenshot_url) {
	var element = Ti.UI.createImageView({
		image : small_screenshot_url,
	});
	if (Utils.isDefined(large_screenshot_url)) {
		var that = this;
		var client = Ti.Network.createHTTPClient({
			// function called when the response data is available
			onload : function(e) {
				element.addEventListener('click', function() {
					Titanium.Platform.openURL(large_screenshot_url);
				});
			},
			// function called when an error occurs, including a timeout
			onerror : function(e) {
				Ti.API.debug("Error " + e.error);
				that.addTitleCentered('no_screenshot');
			},
			timeout : Ti.App.Config.getTimeout()
		});
		client.open("GET", large_screenshot_url);
		client.send();
	}
	return element;
}
// Type : Label, Title, Buttons, ...
// Attr : Records, Menu, ...
View.prototype.getStyleOf = function(type, attr) {
	// We get the style of the element
	var style = this.cloneObject(this.getDTC().styles[type + "s"].generic);

	// We get the specific style for the attribute (registrant, servers, ...)
	var specific_style = this.getDTC().styles[type+"s"][attr];
	if (!this.isUndefined(specific_style)) {
		// overriding generic style with specific
		for (var s in specific_style)
		style[s] = specific_style[s];
	}
	return style;
}

View.prototype.isUndefined = function(variable) {
	return typeof (variable) == "undefined";
}

View.prototype.cloneObject = function(obj) {
	if (null == obj || "object" != typeof obj)
		return obj;
	var copy = obj.constructor();
	for (var attr in obj) {
		if (obj.hasOwnProperty(attr))
			copy[attr] = obj[attr];
	}
	return copy;
}

View.prototype.noInternet = function() {
	alert(this.getDTC().lang.noInternet);
}

module.exports = View;
