var View = require('/ui/common/views/View');
var Utils = require('/ui/common/lib/Utils');
Utils.inherit(ServicesManager, View);

function ServicesManager(masterView) {
	this.masterView = masterView;
	var subWin = Ti.UI.createWindow({
		title : this.getDTC().lang.textServicesManager,
		backgroundColor : this.getDTC().colors.black,
	});

	var presentationView = Ti.UI.createView();

	this.tableView = Ti.UI.createTableView({
		top : 0,
		separatorColor : this.getDTC().colors.white,
		color : this.getDTC().colors.white,
	});

	this.products = new Array();
	this.displayProducts(masterView.getProducts());

	subWin.add(presentationView);
	subWin.add(this.tableView);
	return subWin;
}

ServicesManager.prototype.clearTableView = function() {
	if (Utils.isDefined(this.tableView.data[0])) {
		while (this.tableView.data[0].rowCount > 0) {
			this.tableView.deleteRow(0);
		}
	}
}

ServicesManager.prototype.displayProducts = function(products) {
	this.clearTableView();
	var imageUp = new Array();
	var imageDown = new Array();
	for (var i = 0; i < products.length; i++) {
		var view = Ti.UI.createView();
		var label = Ti.UI.createLabel({
			left : 5,
			color : this.getDTC().colors.white,
			text : this.getDTC().lang[products[i]],
		});

		//Switch
		var switchProducts = Titanium.UI.createSwitch({
			right : this.getDTC().sizes.SMRightSwitch,
			index : i,
			value : true,
		});
		if (Ti.App.Properties.getBool(products[i]) != null) {
			if (!Ti.App.Properties.getBool(products[i])) {
				switchProducts.setValue(false);
			}
		}
		var that = this;
		switchProducts.addEventListener('change', function(e) {
			that.masterView.showActivityIndicator();
			that.masterView.toggleProduct(products[e.source.index], e.source.index);
			Ti.App.Properties.setBool(products[e.source.index], e.source.value);
			Ti.API.debug(products[e.source.index]+" "+Ti.App.Properties.getBool(products[e.source.index]));
		});
		//Down
		imageDown[i] = Ti.UI.createImageView({
			image : this.getDTC().images.down,
			right : this.getDTC().sizes.SMDownSwitch,
			index : i,
		});
		//Up
		imageUp[i] = Ti.UI.createImageView({
			image : this.getDTC().images.up,
			right : this.getDTC().sizes.SMUpSwitch,
			index : i,
		});

		imageUp[i].addEventListener('click', function(e) {
			that.editServices(products, e.source.index, 'up');
		});
		imageDown[i].addEventListener('click', function(e) {
			that.editServices(products, e.source.index, 'down');
		});
		if (i == 0)
			imageUp[i].visible = false;
		if (i == products.length - 1)
			imageDown[i].visible = false;

		var rowProduct = Titanium.UI.createTableViewRow();
		view.add(label);
		view.add(switchProducts);
		view.add(imageDown[i]);
		view.add(imageUp[i]);
		rowProduct.add(view);
		this.tableView.appendRow(rowProduct);
		this.products[products[i]] = rowProduct;
	}
}

ServicesManager.prototype.editServices = function(products, index, action) {
	this.masterView.showActivityIndicator();
	this.tableView.setVisible(false);
	//this.clearTableView();
	if (action == "up") {
		if (index - 1 >= 0) {
			var tmp = products[index - 1];
			products[index - 1] = products[index];
			products[index] = tmp;
		}
		this.masterView.moveProduct(products[index - 1], index, action);
	} else {
		if (index + 1 < products.length) {
			var tmp = products[index + 1];
			products[index + 1] = products[index];
			products[index] = tmp;
			this.masterView.moveProduct(products[index + 1], index, action);
		}
	}
	this.displayProducts(products);
	Ti.App.Properties.setList("products", products);
	this.tableView.setVisible(true);
}

module.exports = ServicesManager;
